/*
 * JOnAS: Java(TM) Open Application Server
 * Copyright (C) 1999 Bull S.A.
 * Contact: jonas-team@objectweb.org
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: ConnectionManagerMBean.java,v 1.4.2.1 2004/09/07 07:53:52 durieuxp Exp $
 * --------------------------------------------------------------------------
 */

package org.objectweb.jonas.dbm;

/**
 * MBean Interface for ConnectionManager (Datasource implementation)
 * Some attributes have a set method (can be changed by admin)
 * MBean type: Standard
 * MBean model: inheritance
 * @author Adriana Danes, Philippe Durieux
 */
public interface ConnectionManagerMBean {

    /**
     * @return String Jndi name of the datasource
     */ 
    public String getDSName();

    /**
     * @return String datasource name (name used for configuration)
     */ 
    public String getDatasourceName();

    /**
     * @return String data source class name
     */ 
    public String getClassName();

    /**
     * @return String data source url
     */ 
    public String getUrl();

    /**
     * @return the description of this datasource
     */
    public String getDataSourceDescription();

    /**
     * @return String data source user
     */ 
    public String getUserName();

    /**
     * @return String data source password
     */ 
    public String getPassword();

    /**
     * @return String Mapper Name
     */ 
    public String getMapperName();

    /**
     * Set the Mapper Name
     * @param mapper mapper name
     */
    public void setMapperName(String mapper);

    /**
     * @return connection level
     */
    public Integer getJDBCConnCheckLevel();

    /**
     * @param level connection level
     */
    public void setJDBCConnCheckLevel(Integer level);

    /**
     * @return connection max age
     */
    public Integer getJDBCConnMaxAge();

    /**
     * @param age connection max age
     */
    public void setJDBCConnMaxAge(Integer mn);

    /**
     * @return connection max open time
     */
    public Integer getJDBCMaxOpenTime();

    /**
     * @param age connection max open time
     */
    public void setJDBCMaxOpenTime(Integer mn);

    /**
     * @return test statement 
     */
    public String getJDBCTestStatement();

    /**
     * @param test test statement 
     */
    public void setJDBCTestStatement(String test);

    /**
     * @return connection pool min
     */
    public Integer getJDBCMinConnPool();

   /**
     * @param min min value for connection pool
     */
    public void setJDBCMinConnPool(Integer min);

    /**
     * @return connection pool max
     */
    public Integer getJDBCMaxConnPool();

   /**
     * @param max max value for connection pool 
     */
    public void setJDBCMaxConnPool(Integer max);

    /**
     * @return max time to wait for a connection, in seconds
     */
    public Integer getJDBCMaxWaitTime();

   /**
     * @param max max time to wait for a connection, in seconds
     */
    public void setJDBCMaxWaitTime(Integer max);

    /**
     * @return max nb of waiters allowed
     */
    public Integer getJDBCMaxWaiters();

   /**
     * @param max max nb of waiters allowed
     */
    public void setJDBCMaxWaiters(Integer max);

    /**
     * @return sampling period in sec.
     */
    public Integer getJDBCSamplingPeriod();

   /**
     * @param sec sampling period
     */
    public void setJDBCSamplingPeriod(Integer sec);

    /**
     * @return Integer number of open connection in this ds
     */
    public Integer getCurrentOpened();

    /**
     * @return Integer number of busy connection in this ds
     */
    public Integer getCurrentBusy();

    /**
     * @return Integer number of connection reserved for tx
     */
    public Integer getCurrentInTx();

    /**
     * @return Integer number of connection served
     */
    public Integer getOpenedCount();

    /**
     * @return Integer number of xa connection served
     */
    public Integer getServedOpen();

    /**
     * @return Integer number of connection failures
     */
    public Integer getConnectionFailures();

    /**
     * @return Integer number of connection leaks
     */
    public Integer getConnectionLeaks();

    /**
     * @return Integer number of open calls that were rejected
     */
    public Integer getRejectedOpen();

    /**
     * @return Integer number of open calls that were rejected
     */
    public Integer getRejectedFull();

    /**
     * @return Integer number of open calls that were rejected
     */
    public Integer getRejectedTimeout();

    /**
     * @return Integer number of open calls that were rejected
     */
    public Integer getRejectedOther();

    /**
     * @return Integer current number of connection waiters
     */
    public Integer getCurrentWaiters();

    /**
     * @return Maximum nb of waiters since datasource creation.
     */
    public Integer getWaitersHigh();

    /**
     * @return Maximum nb of waiters in last sampling period
     */
    public Integer getWaitersHighRecent();

    /**
     * @return Maximum nb of busy connections in last sampling period
     */
    public Integer getBusyMaxRecent();

    /**
     * @return Minimum nb of busy connections in last sampling period
     */
    public Integer getBusyMinRecent();

    /**
     * @return Total nb of waiters since datasource creation.
     */
    public Integer getWaiterCount();

    /**
     * @return Total waiting time (millisec) since datasource creation.
     */
    public Long getWaitingTime();

    /**
     * @return Max waiting time (millisec) since datasource creation.
     */
    public Long getWaitingHigh();

    /**
     * @return Max waiting time (millisec) in last sampling period
     */
    public Long getWaitingHighRecent();

    /**
     * return the type of this data source
     */
    public String getDataSourceType();

    /**
     * save updated configuration
     */
    public void saveConfig();

}
